@@ -1,6 +1,6 @@
 package App::mojopaste;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 1;
 
@@ -12,7 +12,7 @@ App::mojopaste - Pastebin application
 
 =head1 VERSION
 
-0.21
+0.22
 
 =head1 DESCRIPTION
 
@@ -36,49 +36,7 @@ environment variable:
 
   $ PASTE_ENABLE_CHARTS=1 script/mojopaste daemon;
 
-The input chart data can be given as JSON or CSV:
-
-=over 2
-
-=item * Raw morris.js arguments
-
-Example:
-
-  {
-    "data": [
-      { "x": "2015-02-04 15:03", "a": 120, "b": 90 },
-      { "x": "2015-03-14", "a": 75, "b": 65 },
-      { "x": "2015-04", "a": 100, "b": 40 }
-    ],
-    "xkey": "x",
-    "ykeys": ["a", "b"],
-    "labels": ["Series A", "Series B"]
-  }
-
-"xkey" default to "x".
-"ykeys" default to the rest of the keys in the first element in "data",
-excluding xkey.
-"labels" default to "ykeys".
-
-See L<http://morrisjs.github.io/morris.js/lines.html> for more details.
-
-Note that by installing L<JSON.pm|JSON> the input format can be less strict,
-allowing JavaScript notation instead of strict JSON.
-
-=item * Just data
-
-  [
-    // comments are allowed
-    # both "#" and "//" can be used anywhere, but on a line by itself
-    { "x": "2015-02-04 15:03", "a": 120, "b": 90 },
-    { "x": "2015-03-14", "a": 75, "b": 65 },
-    { "x": "2015-04", "a": 100, "b": 40 }
-  ]
-
-This input format takes just an JSON array and will use that as "data".
-The rest will use the default value rules from above.
-
-=item * CSV data
+The input chart data must be valid CSV:
 
 CSV data is similar to L</Just data> above, except the first line is used as
 "xkey,ykey1,ykey2,...". Example:
@@ -91,8 +49,6 @@ CSV data is similar to L</Just data> above, except the first line is used as
 
 CSV input data require L<Text::CSV> to be installed.
 
-=back
-
 =head2 Embedding
 
 A paste can be embedded in other pages using the query param "embed". Examples:
@@ -152,16 +108,12 @@ Example mojopaste.conf:
 
   {
     paste_dir     => '/path/to/paste/dir',
-    allow_robots  => 1, # default is 0
     enable_charts => 1, # default is 0
     hypnotoad => {
       listen => ['http://*:8080'],
     },
   }
 
-"allow_robots" will disable javascript requirements and allow simple
-scripts (robots) to use the pastebin without much knowledge.
-
 "enable_charts" is for adding a button which can make a chart of the input
 data using L<morris.js|http://morrisjs.github.io/morris.js>
 
